Method: CSD.cmd
- Defined in:
- lib/csd/container.rb
.cmd ⇒ Object
This method chooses and holds the command helper instance.
17 18 19 |
# File 'lib/csd/container.rb', line 17 def cmd @@cmd ||= Commands.new end |
This method chooses and holds the command helper instance.
17 18 19 |
# File 'lib/csd/container.rb', line 17 def cmd @@cmd ||= Commands.new end |