Exception: CSD::Error::Graphics::CardNotSupported
- Defined in:
- lib/csd/application/graphics/error.rb
Overview
See ‘csd/error’ to find out which status code range has been assigned to Graphics
See ‘csd/error’ to find out which status code range has been assigned to Graphics