Class: CSD::Options

Inherits:
Object show all
Defined in:
lib/csd/container.rb

Overview

A wrapper for the Options class to be able to run all methods as class methods.

Class Method Summary collapse

Class Method Details

.clear(*args) ⇒ Object

Because the Options class will respond to clear, we must pass it on explicitly to the OptionsParser instance residing in CSD.options



76
77
78
# File 'lib/csd/container.rb', line 76

def self.clear(*args)
  ::CSD.options.clear(*args)
end

.method_missing(meth, *args, &block) ⇒ Object



79
80
81
# File 'lib/csd/container.rb', line 79

def self.method_missing(meth, *args, &block)
  ::CSD.options.send(meth, *args, &block)
end