Class: CSD::PathContainer

Inherits:
OpenStruct
  • Object
show all
Defined in:
lib/csd/path_container.rb

Instance Method Summary collapse

Instance Method Details

#applicationsObject

This method chooses and holds the container for applications.



27
28
29
# File 'lib/csd/path_container.rb', line 27

def applications
  @applications ||= File.expand_path(File.join(self.gem, 'lib', 'csd', 'application'))
end

#gemObject

This method chooses and holds the container for gem.



15
16
17
# File 'lib/csd/path_container.rb', line 15

def gem
  @gem ||= File.expand_path(File.join(File.dirname(__FILE__), '..' ,'..'))
end

#rootObject

This method chooses and holds the container for root privilege.



9
10
11
# File 'lib/csd/path_container.rb', line 9

def root
  @root ||= Dir.pwd
end

#vendorObject

This method chooses and holds the container for vendor.



21
22
23
# File 'lib/csd/path_container.rb', line 21

def vendor
  @vendor ||= File.join(self.gem, 'vendor')
end