Class: CSD::PathContainer
- Defined in:
- lib/csd/path_container.rb
Instance Method Summary collapse
-
#applications ⇒ Object
This method chooses and holds the container for applications.
-
#gem ⇒ Object
This method chooses and holds the container for gem.
-
#root ⇒ Object
This method chooses and holds the container for root privilege.
-
#vendor ⇒ Object
This method chooses and holds the container for vendor.
Instance Method Details
#applications ⇒ Object
This method chooses and holds the container for applications.
27 28 29 |
# File 'lib/csd/path_container.rb', line 27 def applications @applications ||= File.(File.join(self.gem, 'lib', 'csd', 'application')) end |
#gem ⇒ Object
This method chooses and holds the container for gem.
15 16 17 |
# File 'lib/csd/path_container.rb', line 15 def gem @gem ||= File.(File.join(File.dirname(__FILE__), '..' ,'..')) end |
#root ⇒ Object
This method chooses and holds the container for root privilege.
9 10 11 |
# File 'lib/csd/path_container.rb', line 9 def root @root ||= Dir.pwd end |
#vendor ⇒ Object
This method chooses and holds the container for vendor.
21 22 23 |
# File 'lib/csd/path_container.rb', line 21 def vendor @vendor ||= File.join(self.gem, 'vendor') end |